==> stonage-0.0.3.tar.gz: stonage-0.0.3/editor/image.c <==
/*
 * Stonage: a puzzle game
 * Copyright (C) 2001 Luc Saillard <luc@saillard.org>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */

#if defined(HAVE_CONFIG_H)
# include "config.h"
#endif
#include "trace.h"
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gtk/gtkwidget.h>
#include <gtk/gtkpixmap.h>

GtkWidget* gtk_pixmap_new_from_file( const char *filename )
{
  GtkWidget *result;
  GdkPixbuf *pixbuf;
  GdkPixmap *pixmap=NULL;
  GdkBitmap *mask=NULL;

  pixbuf = gdk_pixbuf_new_from_file( filename );
  if (!pixbuf)
   {
     trace( "Could not load `%s'!\n", filename );
     return NULL;
   }

  gdk_pixbuf_render_pixmap_and_mask( pixbuf, &pixmap, &mask, 127 );
  gdk_pixbuf_unref( pixbuf );

  result = gtk_pixmap_new( pixmap, mask );

  if (mask)
    gdk_bitmap_unref( mask );
  if (pixmap)
    gdk_pixmap_unref( pixmap );

  return result;
}

==> stonage-0.0.6.tar.gz: stonage-0.0.6/editor/image.c <==
/*
 * Stonage: a puzzle game
 * Copyright (C) 2001 Luc Saillard <luc@saillard.org>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */

#if defined(HAVE_CONFIG_H)
# include "config.h"
#endif
#include "trace.h"
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gtk/gtkwidget.h>
#include <gtk/gtkpixmap.h>

GtkWidget *
gtk_pixmap_new_from_file(const char *filename )
{
  GtkWidget *result;
  GdkPixbuf *pixbuf;
  GdkPixmap *pixmap=NULL;
  GdkBitmap *mask=NULL;

  pixbuf = gdk_pixbuf_new_from_file( filename );
  if (!pixbuf)
   {
     trace( "Could not load `%s'!\n", filename );
     return NULL;
   }

  gdk_pixbuf_render_pixmap_and_mask( pixbuf, &pixmap, &mask, 127 );
  gdk_pixbuf_unref( pixbuf );

  result = gtk_pixmap_new( pixmap, mask );

  if (mask)
    gdk_bitmap_unref( mask );
  if (pixmap)
    gdk_pixmap_unref( pixmap );

  return result;
}
